Learn R Programming

snazzieR (version 0.1.2)

color.ref: Display a Color Reference Palette

Description

This function generates a plot displaying a predefined color palette with color codes for easy reference. The palette includes shades of Red, Orange, Yellow, Green, Blue, Purple, and Grey.

Usage

color.ref()

Arguments

Value

A plot displaying the color palette.

Details

Light Grey color swatch

Examples

Run this code
color.ref()

Run the code above in your browser using DataLab