powered by
This function generates a plot displaying a predefined color palette with color codes for easy reference. The palette includes shades of Red, Orange, Yellow, Green, Blue, Purple, and Grey.
color.ref()
A plot displaying the color palette.
Run the code above in your browser using DataLab